<?php
/**
 * Seur Get Labels.
 *
 * @package SEUR.
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Seur Get labels from Order
 *
 * @param array $post Data post.
 */
function seur_get_labels_from_order( $post ) {
	global $error;

	if ( ! current_user_can( 'edit_shop_orders' ) ) {
		die( esc_html__( 'Cheatin&#8217; uh?', 'seur' ) );
	}

	$orderid2 = '';
	if ( isset( $_GET['order_id'] ) ) {
		$orderid2 = absint( sanitize_text_field( wp_unslash( $_GET['order_id'] ) ) );
	}
	$order_id = '';
	if ( isset( $_POST['order-id'] ) ) {
		$order_id = sanitize_text_field( wp_unslash( $_POST['order-id'] ) );
	}
	$weight_unit = '';
	$weight_unit = get_option( 'woocommerce_weight_unit' );
	$weight      = '';
	$order_data  = seur_get_order_data( $orderid2 );
	$weight      = $order_data[0]['weight'];
	$shop2       = get_post_meta( $orderid2, '_seur_2shop_codCentro', true );
	$packages    = '';
	$disabled    = ' readonly';

	if ( ! empty( $shop2 ) ) {
		$value = '1';
	} else {
		$value = '';
	}
	if ( ! $orderid2 && ! $order_id ) {
		exit;
	}
	?>
	<div class="wrap">
	<h1 class="wp-heading-inline"><?php esc_html_e( 'Get Labels', 'seur' ); ?></h1>
	<hr class="wp-header-end">
	<?php
	$url = 'https://ws.seur.com/WSEcatalogoPublicos/servlet/XFireServlet/WSServiciosWebPublicos?wsdl';
	if ( ! seur_check_url_exists( $url ) ) {
		die( esc_html__( 'We&apos;re sorry, SEUR API is down. Please try again in few minutes', 'seur' ) );
	}

	if ( $orderid2 && ! $order_id ) {
		?>
		<form method="post" name="getlabels">
			<input type='hidden' name='order-id' class='form-control' value='<?php echo esc_html( $orderid2 ); ?>' />
			<label><?php esc_html_e( 'Packages Weight', 'seur' ); ?></label><br />
			<?php if ( 'kg' === $weight_unit ) { ?>
				<input title="<?php esc_html_e( 'Weight', 'seur' ); ?>" type='text' name='seur-weight' class='form-control' placeholder='<?php esc_html_e( 'EX: 0.300', 'seur' ); ?>' value='<?php if ( $weight ) { echo esc_html( $weight );} ?>' required='' /> <?php
			} elseif ( 'g' === $weight_unit ) { ?>
				<input title="<?php esc_html_e( 'Weight', 'seur' ); ?>" type='text' name='seur-weight' class='form-control' placeholder='<?php esc_html_e( 'EX: 300', 'seur' ); ?>' value='<?php if ( $weight ) { echo esc_html( $weight ); } ?>' required='' />
			<?php } ?><br />
			<label><?php esc_html_e( 'Number of Packages', 'seur' ); ?></label><br />
			<input title="<?php esc_html_e( 'Number of Packages', 'seur' ); ?>" type="text" name="seur-number-packages" class="form-control" placeholder="<?php esc_html_e( 'EX: 2', 'seur' ); ?>" value="<?php echo esc_html( $value ); ?>" required="" <?php if ( ! empty( $shop2 ) ) { echo esc_html( $disabled ); } ?> /><br />
			<?php wp_nonce_field( 'seur_get_label_action', 'seur_get_label_nonce_field' ); ?>
			<input type="submit" class="seur_label_submit button button-primary" value="<?php esc_html_e( 'Get labels', 'seur' ); ?>" />
		</form>
		<br />
		<a class="button" href="#" onclick="self.parent.tb_remove(); self.parent.location.reload()"><?php esc_html_e( 'Close', 'seur' ); ?></a>
		<?php
	} elseif ( $order_id ) {
		if ( isset( $_POST['order-id'] ) && isset( $_POST['seur-weight'] ) && isset( $_POST['seur-number-packages'] ) ) {
			$order_id    = sanitize_text_field( wp_unslash( $_POST['order-id'] ) );
			$weight      = sanitize_text_field( wp_unslash( $_POST['seur-weight'] ) );
			$numpackages = sanitize_text_field( wp_unslash( $_POST['seur-number-packages'] ) );
		} else {
			$order_id    = '';
			$weight      = '';
			$numpackages = '';
		}
		$has_label = '';
		$label_id  = '';

		if ( ! empty( $shop2 ) && $weight > 20 ) {
			$message = __( 'Max Weight 20 Kg', 'seur' );
			die( esc_html( $message ) );
		}

		if ( empty( $weight ) ) {
			$message = __( 'Weight is needed', 'seur' );
			die( esc_html( $message ) );
		}

		if ( empty( $numpackages ) ) {
			$message = __( 'Package number is needed', 'seur' );
			die( esc_html( $message ) );
		}

		if ( ! isset( $_POST['seur_get_label_nonce_field'] ) || ! wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['seur_get_label_nonce_field'] ) ), 'seur_get_label_action' ) ) {
			exit;
		}

		$new_status = seur_after_get_label();
		$has_label  = get_post_meta( $order_id, '_seur_shipping_order_label_downloaded', true );

		if ( 'yes' !== $has_label ) {

			$label = seur_get_label( $order_id, $numpackages, $weight, true );

			$label_result  = $label[0]['result'];
			$labelid       = $label[0]['labelID'];
			$label_message = $label[0]['message'];

			if ( $label_result ) {

				$order = wc_get_order( $order_id );
				$order->update_status( $new_status, __( 'Label have been created:', 'seur' ), true );
				add_post_meta( $order_id, '_seur_shipping_order_label_downloaded', 'yes', true );
				add_post_meta( $order_id, '_seur_shipping_label_id', $labelid, true );
				$order->add_order_note( 'The Label for Order #' . $order_id . ' have been downloaded', 0, true );
				echo esc_html__( 'Label dowloaded, the Label ID is ', 'seur' ) . esc_html( $labelid );
				?>
							<br />
							<a class="button" href="#" onclick="self.parent.tb_remove(); self.parent.location.reload()"><?php esc_html_e( 'Close', 'seur' ); ?></a>
						<?php
			} else {
				echo 'There was an error: ' . esc_html( $label_message );
			}
		} else {
			esc_html_e( 'The Order already has a label', 'seur' );
			?>
				<br />
				<a class="button" href="#" onclick="self.parent.tb_remove(); self.parent.location.reload()"><?php esc_html_e( 'Close', 'seur' ); ?></a>
				<?php
		}
	}
	?>
		</div>
	<?php
}
